@@ -3,20 +3,8 @@
  *
  * Authors: Regis Merlino <regis.merlino@intel.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -26,17 +14,28 @@
  * #GUPnPFeature respresent a Feature element.
  */
 
+#include <config.h>
+
 #include "gupnp-feature.h"
 
+struct _GUPnPFeatureClass {
+        GObjectClass parent_class;
+};
+
 struct _GUPnPFeaturePrivate {
         char *name;
         char *version;
         char *object_ids;
 };
+typedef struct _GUPnPFeaturePrivate GUPnPFeaturePrivate;
+
+struct _GUPnPFeature {
+        GObject parent;
+};
 
 G_DEFINE_TYPE_WITH_PRIVATE (GUPnPFeature,
                             gupnp_feature,
-                            G_TYPE_OBJECT);
+                            G_TYPE_OBJECT)
 
 enum {
         PROP_0,
@@ -48,9 +47,6 @@ enum {
 static void
 gupnp_feature_init (GUPnPFeature *object)
 {
-        object->priv = G_TYPE_INSTANCE_GET_PRIVATE (object,
-                                                    GUPNP_TYPE_FEATURE,
-                                                    GUPnPFeaturePrivate);
 }
 
 static void
@@ -59,7 +55,8 @@ gupnp_feature_finalize (GObject *object)
         GObjectClass        *object_class;
         GUPnPFeaturePrivate *priv;
 
-        priv = GUPNP_FEATURE (object)->priv;
+        priv = gupnp_feature_get_instance_private (GUPNP_FEATURE (object));
+
         g_free (priv->name);
         g_free (priv->version);
         g_free (priv->object_ids);
@@ -101,19 +98,18 @@ gupnp_feature_set_property (GObject      *object,
                             const GValue *value,
                             GParamSpec   *pspec)
 {
-        GUPnPFeature *feature;
-
-        feature = GUPNP_FEATURE (object);
+        GUPnPFeaturePrivate *priv =
+                gupnp_feature_get_instance_private (GUPNP_FEATURE (object));
 
         switch (property_id) {
         case PROP_NAME:
-                feature->priv->name = g_value_dup_string (value);
+                priv->name = g_value_dup_string (value);
                 break;
         case PROP_VERSION:
-                feature->priv->version = g_value_dup_string (value);
+                priv->version = g_value_dup_string (value);
                 break;
         case PROP_OBJECT_IDS:
-                feature->priv->object_ids = g_value_dup_string (value);
+                priv->object_ids = g_value_dup_string (value);
                 break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -198,7 +194,10 @@ gupnp_feature_class_init (GUPnPFeatureClass *klass)
 const char *
 gupnp_feature_get_name (GUPnPFeature *feature)
 {
-        return feature->priv->name;
+        GUPnPFeaturePrivate *priv =
+                gupnp_feature_get_instance_private (GUPNP_FEATURE (feature));
+
+        return priv->name;
 }
 
 /**
@@ -212,7 +211,10 @@ gupnp_feature_get_name (GUPnPFeature *feature)
 const char *
 gupnp_feature_get_version (GUPnPFeature *feature)
 {
-        return feature->priv->version;
+        GUPnPFeaturePrivate *priv =
+                gupnp_feature_get_instance_private (GUPNP_FEATURE (feature));
+
+        return priv->version;
 }
 
 /**
@@ -226,5 +228,8 @@ gupnp_feature_get_version (GUPnPFeature *feature)
 const char *
 gupnp_feature_get_object_ids (GUPnPFeature *feature)
 {
-        return feature->priv->object_ids;
+        GUPnPFeaturePrivate *priv =
+                gupnp_feature_get_instance_private (GUPNP_FEATURE (feature));
+
+        return priv->object_ids;
 }
